import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, ParamMap, Router } from '@angular/router';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { filter, switchMap } from 'rxjs/operators';
import { Format } from 'src/app/models/format.model';
import { DataLogsService } from 'src/app/services/data-logs.service';

@Component({
  selector: 'app-logs-pre-report',
  templateUrl: './logs-pre-report.component.html',
  styleUrls: ['./logs-pre-report.component.scss'],
})
export class LogsPreReportComponent implements OnInit {

  responseArray: any = [];
  form: FormGroup;
  title: string;
  type: string ;
  id: string;
  serviceName:string;
  nbObjects: number = 0;
  isSession:boolean = false;

  constructor(
    private _dataLogsService: DataLogsService,
    private _route: ActivatedRoute,
    private _router: Router,
    private _fb: FormBuilder,
  ) {
  }

  ngOnInit() {
    this.title = this._route.snapshot.data.title;
    this.id = this._route.snapshot.paramMap.get('id');
    this.type = this._route.snapshot.paramMap.get('type');
    if (this.type === 'session') {
      this.isSession = true;
    }

    this._route.paramMap.pipe(
      filter((paramMap: ParamMap) => (paramMap.get('id') !== null)),
      filter((paramMap: ParamMap) => (paramMap.get('type') !== null)),
      switchMap((paramMap: ParamMap) => this._dataLogsService.getComplementaryFromSlugOrSession(
        paramMap.get('type'),
        paramMap.get('id'))))
      .subscribe((response) => {

        this.responseArray = response[0];
        if (this.type === 'session') {
          this.nbObjects = response[0].slug_list.length;
        } else {
          this.nbObjects = response[0].session_id_list.length;
        }
        // console.log('responseArray: ', this.responseArray);
        // console.log('nbObjects: ', this.nbObjects);

      });
  }

}
