import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, ParamMap, Router } from '@angular/router';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { filter, switchMap } from 'rxjs/operators';
import { Format } from 'src/app/models/format.model';
import { DataLogsService } from 'src/app/services/data-logs.service';

@Component({
  selector: 'app-logs-report',
  templateUrl: './logs-report.component.html',
  styleUrls: ['./logs-report.component.scss'],
})
export class LogsReportComponent implements OnInit {

  responseArray: any = [];
  form: FormGroup;
  title: string;
  slug: string ;
  uuid:string;
  previousUrl: string ;
  sessionId: string;
  serviceName:string;
  nbObjects: number = 0;
  urlCode: string = '';
  isSession:boolean = false;

  constructor(
    private _dataLogsService: DataLogsService,
    private _route: ActivatedRoute,
    private _router: Router,
    private _fb: FormBuilder,
  ) {
  }

  ngOnInit() {
    this.title = this._route.snapshot.data.title;
    this.sessionId = this._route.snapshot.paramMap.get('sessionId');
    this.slug = this._route.snapshot.paramMap.get('slug');
    this.urlCode = this._route.snapshot.paramMap.get('urlCode');
    if (this.urlCode === 'session') {
      this.previousUrl = `/datalogs/preReport/session/${this.sessionId}`;

    } else if (this.urlCode === 'slug') {
      this.previousUrl = `/datalogs/preReport/slug/${this.slug}`;
    } else {
      this.previousUrl = '/datalogs';
    }
    this.getUuidFromSlug(this.slug);
  }

  getUuidFromSlug(slug) {
    this._dataLogsService.getUuidFromSlug(slug).subscribe((result) => {
      // console.log(result[0]);
      this.uuid = result[0].uuid_list[0];
    },
    );
  }

}
