import { Component, OnInit } from '@angular/core';
import { Resource, ResourceRO } from 'src/app/models/resource.model';
import { ResourceService } from 'src/app/services/resource.service';
import { Subscription } from 'rxjs';
import { PaginatorOptions } from 'src/app/models/paginator-options.model';
import { IPageHeaderInfo } from '../../../models/page.model';

@Component({
  selector: 'app-resources',
  templateUrl: './resources.component.html',
  styleUrls: ['./resources.component.scss'],
})
export class ResourcesComponent implements OnInit {

  pageHeaderInfo: IPageHeaderInfo = {
    title: '',
  };
  resources: Resource[];
  searchChangeSub: Subscription;

  // Paginator options
  paginator: PaginatorOptions;

  sortValue: string;

  totalElement: number;
  pageSize = 10;
  pageSizeOptions = [5, 10, 25, 100];
  filters = {
    name: '',
  };
  where = {};

  constructor(
    private resourcesService: ResourceService,
  ) {
    this.paginator = {
      pageIndex: this.resourcesService.pageNumber,
      length: 0,
      limit: this.resourcesService.limit,
      pageSizeOptions: [5, 10, 20],
    };
  }

  ngOnInit(): void {
    this.resourcesService.sortOptions = {
      value: 'name',
      order: 'asc',
    };
    this.search();

    this.searchChangeSub = this.resourcesService.searchChange$.subscribe(
      () => {
        this.search();
      },
    );
  }

  private search() {
    this.resourcesService.getResources()
      .subscribe((items: ResourceRO) => {
        this.resources = items.resources;
        this.totalElement = items.totalCount;

        this.pageHeaderInfo.title = `${this.totalElement} ressources trouvées`;

        this.paginator.limit = this.resourcesService.limit;
        this.paginator.pageIndex = this.resourcesService.pageNumber;
        this.paginator.length = items.totalCount;
      });
  }

  // When pagination is changed by user, we update datasetList with new pagination options
  changePagination(pageIndex) {
    this.resourcesService.paginationChanged(this.paginator.limit, pageIndex);
  }

  changePageSize(pageSize) {
    this.resourcesService.paginationChanged(pageSize, 1);
  }

  sortBy(key: string) {
    if (this.resourcesService.sortOptions.value === key) {
      this.resourcesService.reverseSortOrder();
    } else {
      this.resourcesService.sortOptions.value = key;
      this.resourcesService.sortOptions.order = 'asc';
    }
    this.search();
  }

  get sortOptions() {
    return this.resourcesService.sortOptions;
  }

  displayDeletePopup(resourceId) {
    const pop = confirm('Etes vous sûr de vouloir supprimer cette ressource ?');
    if (pop) {
      this.resourcesService.delete(resourceId).subscribe(() => {
        this.resourcesService.pageNumber = 1;
        this.search();
      });
    }
  }
}
